# Fact Sheet Modeling Guidelines
This section is your go-to resource for effectively modeling your organization with SAP LeanIX. Whether you're a beginner or an expert, you will find essential information to get started in the subpages of this documentation.
Access our curated guides for modeling your organization with SAP LeanIX. Here, you'll discover detailed guidelines on modeling the meta model effectively. You will learn the key concepts of what are fact sheet types, their subtypes, the best practices, and the anti-pattern of using each fact sheet type.
